@@ -62,33 +62,41 @@ class Environment(object):
     # variables typically populated programatically
     warmed_up = False  # returns true if the environment is ready for environments
     _formula_dict = {}  # a dictionary of existing formula instances to pull from
+    sprinter_namespace = None  # the namespace to make installs with. this affects:
+    # the prefix added to injections
 
-    def __init__(self, logger=None, logging_level=logging.INFO):
+    def __init__(self, logger=None, logging_level=logging.INFO, root=None, sprinter_namespace='sprinter'):
         self.system = System()
         if not logger:
             logger = self._build_logger(level=logging.INFO)
         logger.setLevel(logging_level)
         self.logger = logger
+        self.sprinter_namespace = sprinter_namespace
+        self.root = root or os.path.expanduser(os.path.join("~", ".%s" % sprinter_namespace))
         if logging_level == logging.DEBUG:
             self.logger.info("Starting in debug mode...")
 
     @warmup
     def install(self):
         """ Install the environment """
-        if not self.directory.new:
-            self.logger.info("Namespace %s already exists!" % self.namespace)
-            self.source = self.config.set_source(Manifest(self.directory.manifest_path))
-            return self.update()
-        self.logger.info("Installing environment %s..." % self.namespace)
-        self.directory.initialize()
-        self._specialize_contexts()
-        for feature in self.config.installs():
-            self.install_feature(feature)
-        self.injections.inject("~/.bash_profile", "[ -d %s ] && . %s/.rc" %
-                               (self.directory.root_dir, self.directory.root_dir))
-        self.injections.inject("~/.bashrc", "[ -d %s ] && . %s/.rc" %
-                               (self.directory.root_dir, self.directory.root_dir))
-        self._finalize()
+        try:
+            if not self.directory.new:
+                self.logger.info("Namespace %s already exists!" % self.namespace)
+                self.source = self.config.set_source(Manifest(self.directory.manifest_path))
+                return self.update()
+            self.logger.info("Installing environment %s..." % self.namespace)
+            self.directory.initialize()
+            self._specialize_contexts()
+            for feature in self.config.installs():
+                self.install_feature(feature)
+            self.inject_environment_rc()
+            self._finalize()
+        except Exception, e:
+            self.logger.error("An error occured during installation!")
+            self.clear_environment_rc()
+            self.logger.info("Removing installation %s..." % self.namespace)
+            self.directory.remove()
+            raise e
         
     @warmup
     @install_required
@@ -112,9 +120,9 @@ class Environment(object):
         self._specialize_contexts()
         for feature in self.config.removes():
             self.remove_feature(feature)
-        self.injections.clear("~/.bash_profile")
+        self.clear_environment_rc()
         self.directory.remove()
-        self._finalize()
+        self.injections.commit()
 
     @warmup
     @install_required
@@ -125,7 +133,7 @@ class Environment(object):
         self._specialize_contexts()
         for feature in self.config.deactivations():
             self.deactivate_feature(feature)
-        self.injections.clear("~/.bash_profile")
+        self.clear_environment_rc()
         self._finalize()
 
     @warmup
@@ -137,10 +145,7 @@ class Environment(object):
         self._specialize_contexts()
         for feature in self.config.activations():
             self.activate_feature(feature)
-        self.injections.inject("~/.bash_profile", "[ -d %s ] && . %s/.rc" %
-                               (self.directory.root_dir, self.directory.root_dir))
-        self.injections.inject("~/.bashrc", "[ -d %s ] && . %s/.rc" %
-                               (self.directory.root_dir, self.directory.root_dir))
+        self.inject_environment_rc()
         self._finalize()
 
     @warmup
@@ -187,25 +192,45 @@ class Environment(object):
             invalidations += self.validate_feature(self, s)
         return invalidations
 
+    @warmup
+    def inject_environment_rc(self):
+        self.injections.inject("~/.profile", "[ -d %s ] && . %s/.rc" %
+                               (self.directory.root_dir, self.directory.root_dir))
+        self.injections.inject("~/.bash_profile", "[ -d %s ] && . %s/.rc" %
+                               (self.directory.root_dir, self.directory.root_dir))
+        self.injections.inject("~/.bashrc", "[ -d %s ] && . %s/.rc" %
+                               (self.directory.root_dir, self.directory.root_dir))
+
+    @warmup
+    def clear_environment_rc(self):
+        self.injections.clear("~/.profile")
+        self.injections.clear("~/.bash_profile")
+        self.injections.clear("~/.bashrc")
+
     def _warmup(self):
         """ initialize variables necessary to perform a sprinter action """
         self.logger.debug("Warming up...")
-        if not isinstance(self.source, Manifest) and self.source:
-            self.source = Manifest(self.source)
-        if not isinstance(self.target, Manifest) and self.target:
-            self.target = Manifest(self.target)
+        try:
+            if not isinstance(self.source, Manifest) and self.source:
+                self.source = Manifest(self.source)
+            if not isinstance(self.target, Manifest) and self.target:
+                self.target = Manifest(self.target)
+        except self.lib.BadCredentialsException, e:
+            self.logger.error(str(e))
+            raise SprinterException("Fatal error! Bad credentials to grab manifest!")
         self.config = Config(source=self.source, target=self.target,
                              namespace=self.namespace)
         if not self.namespace:
             self.namespace = self.config.namespace
         if not self.directory:
-            self.directory = Directory(self.namespace)
-        self.injections = Injections(wrapper="SPRINTER_%s" % self.namespace)
+            self.directory = Directory(self.namespace, sprinter_root=self.root)
+        self.injections = Injections(wrapper="%s_%s" % (self.sprinter_namespace.upper(), self.namespace))
         # install virtualenv
-        self._install_sandbox('virtualenv', virtualenv.create_environment,
-                              {'use_distribute': True})
-        if self.system.isOSX():
-            self._install_sandbox('brew', brew.install_brew)
+        if self.target:
+            self._install_sandbox('virtualenv', virtualenv.create_environment,
+                                  {'use_distribute': True})
+            if self.system.isOSX():
+                self._install_sandbox('brew', brew.install_brew)
         # append the bin, in the case sandboxes are necessary to
         # execute commands further down the sprinter lifecycle
         os.environ['PATH'] = self.directory.bin_path() + ":" + os.environ['PATH']
@@ -218,6 +243,8 @@ class Environment(object):
             self.config.write(open(self.directory.manifest_path, "w+"))
         if self.directory.rewrite_rc:
             self.directory.add_to_rc("export PATH=%s:$PATH" % self.directory.bin_path())
+            self.directory.add_to_rc("export LIBRARY_PATH=%s:$LIBRARY_PATH" % self.directory.lib_path())
+            self.directory.add_to_rc("export C_INCLUDE_PATH=%s:$C_INCLUDE_PATH" % self.directory.include_path())
         self.injections.commit()
 
     def _install_sandbox(self, name, call, kwargs={}):
@@ -256,7 +283,9 @@ class Environment(object):
         self.config.grab_inputs()
         for manifest in [self.source, self.target]:
             context_dict = {}
-            for s in manifest.formula_sections():
-                context_dict["%s:root_dir" % s] = self.directory.install_directory(s)
-            context_dict['config:node'] = self.system.node
-            manifest.add_additional_context(context_dict)
+            if manifest:
+                for s in manifest.formula_sections():
+                    context_dict["%s:root_dir" % s] = self.directory.install_directory(s)
+                    context_dict['config:root_dir'] = self.directory.root_dir
+                    context_dict['config:node'] = self.system.node
+                manifest.add_additional_context(context_dict)
