@@ -19,14 +19,14 @@ class TemplateFormula(FormulaBase):
 
     def install(self, feature_name, config):
         self.__install_file(config['source'], config['target'], config)
-        super(TemplateFormula, self).setup(feature_name, config)
+        super(TemplateFormula, self).install(feature_name, config)
 
     def update(self, feature_name, source_config, target_config):
         self.__install_file(target_config['source'], target_config['target'], target_config)
         super(TemplateFormula, self).update(feature_name, source_config, target_config)
 
     def remove(self, feature_name, config):
-        super(TemplateFormula, self).destroy(feature_name, config)
+        super(TemplateFormula, self).remove(feature_name, config)
 
     def __install_file(self, source, target_file, config):
         source_content = None
