@@ -11,6 +11,9 @@ from sprinter import lib
 from sprinter.environment import Environment
 from sprinter.manifest import Manifest
 from sprinter.directory import Directory
+from sprinter.exceptions import SprinterException, BadCredentialsException
+
+env = None
 
 description = \
 """
@@ -26,24 +29,24 @@ parser = OptionParser(description=description)
 #                     help="The operation that sprinter should run (install, deactivate, activate, switch)")
 # parser.add_option('target', metavar='T', help="The path to the manifest file to install", nargs='?')
 parser.add_option('--namespace', dest='namespace', default=None,
-                    help="Namespace to check environment against")
+                  help="Namespace to check environment against")
 parser.add_option('--username', dest='username', default=None,
-                    help="Username if the url requires authentication")
+                  help="Username if the url requires authentication")
 parser.add_option('--auth', dest='auth', action='store_true',
-                    help="Specifies authentication is required")
+                  help="Specifies authentication is required")
 parser.add_option('--password', dest='password', default=None,
-                    help="Password if the url requires authentication")
+                  help="Password if the url requires authentication")
 parser.add_option('-v', dest='verbose', action='store_true', help="Make output verbose")
 # not implemented yet
 parser.add_option('--sandboxbrew', dest='sandbox_brew', default=False,
-                    help="if true, sandbox a brew installation, alternatively, " + \
-                         "false will disable brew sandboxes for configuration that request it.")
+                  help="if true, sandbox a brew installation, alternatively, " +
+                  "false will disable brew sandboxes for configuration that request it.")
 parser.add_option('--sandboxaptget', dest='sandbox_aptget', default=False,
-                    help="if true, sandbox an apt-get installation, alternatively, " +
-                         "false will disable apt-get sandboxes for configuration that request it.")
+                  help="if true, sandbox an apt-get installation, alternatively, " +
+                  "false will disable apt-get sandboxes for configuration that request it.")
 parser.add_option('--virtualenv', dest='virtualenv', default=False,
-                    help="if true, will virtualenv sprinter and install eggs relative to it, " +
-                         "false will disable apt-get sandboxes for configuration that request it.")
+                  help="if true, will virtualenv sprinter and install eggs relative to it, " +
+                  "false will disable apt-get sandboxes for configuration that request it.")
 
 
 def signal_handler(signal, frame):
@@ -53,7 +56,14 @@ def signal_handler(signal, frame):
 
 def main():
     signal.signal(signal.SIGINT, signal_handler)
-    parse_args(sys.argv[1:])
+    try:
+        parse_args(sys.argv[1:])
+    except SprinterException, e:
+        print str(e)
+        print "Sprinter shut down with an error!"
+    except BadCredentialsException, e:
+        print str(e)
+        print "Invalid username and password combination!"
 
 
 def error(message):
@@ -74,6 +84,12 @@ def parse_args(argv, Environment=Environment):
     env = Environment(logging_level=logging_level)
 
     if command == "install":
+        def handle_install_shutdown(signal, frame):
+            print "Removing install..."
+            env.directory.remove()
+            env.clear_environment_rc()
+            signal_handler(signal, frame)
+        signal.signal(signal.SIGINT, handle_install_shutdown)
         if options.username or options.auth:
             options = get_credentials(options, parse_domain(target))
             target = Manifest(target, username=options.username, password=options.password)
