@@ -17,6 +17,7 @@ from StringIO import StringIO
 
 from sprinter import lib
 from sprinter.dependencytree import DependencyTree, DependencyTreeException
+from sprinter.system import System
 
 CONFIG_RESERVED = ['source', 'inputs']
 FEATURE_RESERVED = ['rc', 'command', 'phase']
@@ -51,6 +52,7 @@ class Manifest(object):
                                              password=password)
         self.namespace = namespace if namespace else self.__parse_namespace()
         self.dtree = self.__generate_dependency_tree()
+        self.system = System(logger=self.logger)
 
     def source(self):
         """
@@ -93,13 +95,25 @@ class Manifest(object):
         for s in self.formula_sections():
             for k, v in self.manifest.items(s):
                 context_dict["%s:%s" % (s, k)] = v
-        return context_dict
+        return_dict = dict(context_dict.items() + self.additional_context_variables.items())
+        return_dict_escaped = dict([("%s|escaped" % k, re.escape(v or "")) for k, v in return_dict.items()])
+        return dict(return_dict.items() + return_dict_escaped.items())
 
     def run_phase(self, feature, phase_name):
         """ Determine if the feature should run in the given phase """
-        return (not self.manifest.has_option(feature, 'phases') or
-                phase_name in [x.strip() for x in self.manifest.get(feature, 'phases').split(",")])
-
+        should_run = True
+        if(self.manifest.has_option(feature, 'phases') and
+                phase_name not in [x.strip() for x in self.manifest.get(feature, 'phases').split(",")]):
+            return False
+        if self.manifest.has_option(feature, 'systems'):
+            should_run = False
+            valid_systems = [s.lower() for s in self.manifest.get(feature, 'systems').split(",")]
+            for system_type, param in [('isOSX', 'osx'),
+                                       ('isDebianBased', 'debian')]:
+                if param in valid_systems and getattr(self.system, system_type)() is True:
+                    should_run = True
+        return should_run
+                    
     def add_additional_context(self, additonal_context):
         """ Add additional context variable """
         self.additional_context_variables = dict(self.additional_context_variables.items() + additonal_context.items())
@@ -237,7 +251,7 @@ class Config(object):
     def installs(self):
         """ Return a list of the features which need to be installed. """
         if not self.target:
-            raise ConfigException("Update method requires a target manifest!")
+            raise ConfigException("Install method requires a target manifest!")
         return [s for s in self.target.formula_sections()
                 if self.target.run_phase(s, "setup")
                 if not self.source or not self.source.has_section(s)]
