@@ -4,6 +4,7 @@ from nose import tools
 from mock import Mock, call
 
 from sprinter.manifest import Config, ConfigException, Manifest, ManifestException
+from sprinter.system import System
 
 manifest_correct_dependency = """
 [sub]
@@ -18,7 +19,6 @@ formula = sprinter.formulas.package
 apt-get = git-core
 brew = git
 """
-
 manifest_incorrect_dependency = """
 [config]
 namespace = sprinter
@@ -28,7 +28,6 @@ formula = sprinter.formulas.git
 depends = sub
 """
 
-
 test_input_string = """
 gitroot==~/workspace
 username
@@ -36,6 +35,23 @@ password?
 main_branch==comp_main
 """
 
+osx_only_manifest = """
+[osx]
+systems = osx
+formula = sprinter.formulas.template
+
+[osx2]
+systems = OsX
+formula = sprinter.formulas.template
+"""
+
+debian_only_manifest = """
+[debian]
+systems = debian
+formula = sprinter.formulas.template
+
+"""
+
 
 class TestManifest(object):
     """
@@ -82,28 +98,45 @@ class TestManifest(object):
 
     def test_get_context_dict(self):
         """ Test getting a config dict """
-        tools.eq_(self.manifest_old.get_context_dict(),
-                  {'sub:bc': 'temp=`pwd`; cd %(sub:testvar)s/libexec && . sub-init2 && cd $tmp',
-                   'mysql:apt-get': 'libmysqlclient\nlibmysqlclient-dev',
-                   'maven:formula': 'sprinter.formulas.unpack',
-                   'ant:specific_version': '1.8.4',
-                   'git:formula': 'sprinter.formulas.package',
-                   'sub:formula': 'sprinter.formulas.git',
-                   'maven:specific_version': '2.10',
-                   'sub:branch': 'yusuke',
-                   'ant:formula': 'sprinter.formulas.unpack',
-                   'mysql:brew': 'mysql',
-                   'git:apt-get': 'git-core',
-                   'sub:url': 'git://github.com/Toumorokoshi/sub.git',
-                   'ant:phases': 'update',
-                   'sub:depends': 'git',
-                   'mysql:formula': 'sprinter.formulas.package',
-                   'sub:rc': 'temp=`pwd`; cd %(sub:root_dir)s/libexec && . sub-init2 && cd $tmp',
-                   'git:brew': 'git'})
+        context_dict = self.manifest_old.get_context_dict()
+        test_dict = {'maven:formula': 'sprinter.formulas.unpack',
+                     'config:hobopopo': 'no',
+                     'maven:specific_version': '2.10',
+                     'ant:formula': 'sprinter.formulas.unpack',
+                     'mysql:formula': 'sprinter.formulas.package',
+                     'sub:rc': 'temp=`pwd`; cd %(sub:root_dir)s/libexec && . sub-init2 && cd $tmp',
+                     'ant:specific_version': '1.8.4',
+                     'sub:formula': 'sprinter.formulas.git',
+                     'sub:branch': 'yusuke',
+                     'git:apt-get': 'git-core',
+                     'sub:url': 'git://github.com/Toumorokoshi/sub.git',
+                     'ant:phases': 'update',
+                     'sub:depends': 'git',
+                     'config:namespace': 'sprinter',
+                     'sub:bc': 'temp=`pwd`; cd %(sub:testvar)s/libexec && . sub-init2 && cd $tmp',
+                     'mysql:apt-get': 'libmysqlclient\nlibmysqlclient-dev',
+                     'config:username': 'toumorokoshi',
+                     'config:gitroot': '~/workspace',
+                     'mysql:brew': 'mysql',
+                     'git:brew': 'git',
+                     'git:formula': 'sprinter.formulas.package',
+                     'config:test_variable': 'test',
+                     'config:inputs': 'sourceonly'}
+        for k, v in test_dict.items():
+            tools.eq_(context_dict[k], v)
+        self.manifest_old.add_additional_context({"config:test": "testing this"})
+        assert "config:test" in self.manifest_old.get_context_dict()
+
+    def test_get_context_dict_escaped_character(self):
+        """ Test getting a config dict with escaping filter will properly escape a character"""
+        manifest = Manifest(StringIO(manifest_escaped_parameters))
+        context_dict = manifest.get_context_dict()
+        assert "section:escapeme|escaped" in context_dict
+        tools.eq_(context_dict["section:escapeme|escaped"], "\!\@\#\$\%\^\&\*\(\)\\\"\\'\~\`\/\?\<\>")
 
     def test_run_phase(self):
         """
-        Run phase should sallow phases that are specifically listed, and
+        Run phase should allow phases that are specifically listed, and
         disallow ones that are not
         """
         assert self.manifest_old.run_phase('ant', 'update'), \
@@ -113,7 +146,28 @@ class TestManifest(object):
         assert self.manifest_old.run_phase('sub', 'deactivate'), \
             "Deactivate not run in feature that does not specify phase!"
 
-    def test_add_additonal_context(self):
+    def test_osx_only(self):
+        """ Test a feature that should only occur on osx """
+        test_manifest = Manifest(StringIO(osx_only_manifest))
+        test_manifest.system = Mock()
+        test_manifest.system.isOSX = Mock(return_value=True)
+        assert test_manifest.run_phase('osx', 'install')
+        assert test_manifest.run_phase('osx2', 'install')
+        test_manifest.system.isOSX = Mock(return_value=False)
+        assert not test_manifest.run_phase('osx', 'install')
+        assert not test_manifest.run_phase('osx2', 'install')
+
+    def test_debianbased_only(self):
+        """ Test a feature that should only occur on debian-based distributions """
+        test_manifest = Manifest(StringIO(debian_only_manifest))
+        test_manifest.system = Mock(spec=System)
+        test_manifest.system.isDebianBased = Mock(return_value=True)
+        assert test_manifest.run_phase('debian', 'install')
+        test_manifest.system.isDebianBased = Mock(return_value=False)
+        assert not test_manifest.run_phase('debian', 'install')
+        assert not test_manifest.run_phase('debian', 'update')
+
+    def test_add_additional_context(self):
         """ Test the add additonal context method """
         self.manifest_old.add_additional_context({'testme': 'testyou'})
         assert 'testme' in self.manifest_old.additional_context_variables
@@ -163,6 +217,14 @@ username = toumorokoshi
 gitroot = ~/workspace
 """
 
+manifest_escaped_parameters = """
+[section]
+namespace = sprinter
+username = toumorokoshi
+gitroot = ~/workspace
+escapeme = !@#$%^&*()"'~`/?<>
+"""
+
 
 manifest_new = """
 [config]
